@@ -24,15 +24,10 @@ class Circle(Model):
     jabberID = models.CharField(max_length=255, blank=True, null=True, unique=True)
     jabberRoom = models.BooleanField(default=True)
 
-    class Meta:
+    class Meta(Model.Meta):
         auto_author = 'owner'
-        owner_field = 'owner'
         nested_fields = ["team", 'members']
         permission_classes = [CirclePermissions]
-        anonymous_perms = ["view"]
-        authenticated_perms = ["inherit", "add"]
-        owner_perms = ["inherit", "change", "delete"]
-        container_path = 'circles/'
         rdf_type = 'hd:circle'
 
     def __str__(self):
@@ -50,12 +45,12 @@ class CircleMember(Model):
     def __str__(self):
         return str(self.circle.name) + " - " + str(self.user.name())
 
-    class Meta:
+    class Meta(Model.Meta):
         container_path = "circle-members/"
         permission_classes = [CircleMemberPermissions]
-        authenticated_perms = ["view", "add"]
-        owner_perms = ["view", "add", "delete"]
-        owner_field = "user"
+        anonymous_perms = []
+        authenticated_perms = []
+        owner_perms = []
         unique_together = ['user', 'circle']
 
     def save(self, *args, **kwargs):
